@@ -13,11 +13,13 @@ miquire :mui, 'sub_parts_retweet'
 miquire :mui, 'sub_parts_quote'
 miquire :mui, 'markup_generator'
 miquire :mui, 'special_edge'
+miquire :mui, 'photo_pixbuf'
 miquire :lib, 'uithreadonly'
 
 # 一つのMessageをPixbufにレンダリングするためのクラス。名前は言いたかっただけ。クラス名まで全てはつね色に染めて♪
-# 情報を設定してから、 Gdk::MiraclePainter#pixbuf で表示用の Gdk::Pixbuf のインスタンスを得ることができる。
+# 情報を設定してから、 Gdk::MiraclePainter#pixbuf で表示用の GdkPixbuf::Pixbuf のインスタンスを得ることができる。
 class Gdk::MiraclePainter < Gtk::Object
+  extend Gem::Deprecate
 
   type_register
   signal_new(:modified, GLib::Signal::RUN_FIRST, nil, nil)
@@ -36,15 +38,17 @@ class Gdk::MiraclePainter < Gtk::Object
   BLACK = [0, 0, 0].freeze
 
   attr_reader :message, :p_message, :tree, :selected
-  alias :to_message :message
+
+  # :nodoc:
+  def to_message
+    message end
+  deprecate :to_message, :none, 2017, 5
 
   # @@miracle_painters = Hash.new
 
   # _message_ を内部に持っているGdk::MiraclePainterの集合をSetで返す。
   # ログ数によってはかなり重い処理なので注意
   def self.findbymessage(message)
-    type_strict message => :to_message
-    message = message.to_message
     result = Set.new
     Gtk::TimeLine.timelines.each{ |tl|
       found = tl.get_record_by_message(message)
@@ -54,8 +58,6 @@ class Gdk::MiraclePainter < Gtk::Object
 
   # findbymessage のdeferred版。
   def self.findbymessage_d(message)
-    type_strict message => :to_message
-    message = message.to_message
     result = Set.new
     Gtk::TimeLine.timelines.deach{ |tl|
       if not tl.destroyed?
@@ -69,18 +71,16 @@ class Gdk::MiraclePainter < Gtk::Object
     @mp_modifier ||= lambda { |miracle_painter|
       if (not miracle_painter.destroyed?) and (not miracle_painter.tree.destroyed?)
         miracle_painter.tree.model.each{ |model, path, iter|
-          if iter[0].to_i == miracle_painter.message[:id]
+          if iter[0] == miracle_painter.message.uri.to_s
             miracle_painter.tree.queue_draw
             break end } end
       false } end
 
   def initialize(message, *coodinate)
-    type_strict message => :to_message
     @p_message = message
-    @message = message.to_message
+    @message = message
     @selected = false
     @pixbuf = nil
-    type_strict @message => Message
     super()
     coordinator(*coodinate)
     ssc(:modified, &Gdk::MiraclePainter.mp_modifier)
@@ -114,7 +114,7 @@ class Gdk::MiraclePainter < Gtk::Object
     @pixmap ||= gen_pixmap
   end
 
-  # TLに表示するための Gdk::Pixbuf のインスタンスを返す
+  # TLに表示するための GdkPixbuf::Pixbuf のインスタンスを返す
   def pixbuf
     return @pixbuf if @pixbuf
     if visible?
@@ -125,7 +125,8 @@ class Gdk::MiraclePainter < Gtk::Object
       @pixbuf
     else
       @last_modify_height = height
-      Gdk::WebImageLoader.loading_pixbuf(@last_modify_height, @last_modify_height) end
+      Skin['loading.png'].pixbuf(width: @last_modify_height, height: @last_modify_height)
+    end
   end
 
   # MiraclePainterの座標x, y上でポインティングデバイスのボタン1が押されたことを通知する
@@ -149,9 +150,14 @@ class Gdk::MiraclePainter < Gtk::Object
       iob_clicked(x, y)
       if not textselector_range
         index = main_pos_to_index(x, y)
-        if index
+        if index and message.links.respond_to?(:segment_by_index)
           l = message.links.segment_by_index(index)
-          l[:callback].call(l) if l and l[:callback] end end
+          if l
+            case
+            when l[:callback]
+              l[:callback].call(l)
+            when l[:open]
+              Plugin.call(:open, l[:open]) end end end end
     when 3
       @tree.get_ancestor(Gtk::Window).set_focus(@tree)
       Plugin::GUI::Command.menu_pop
@@ -261,7 +267,7 @@ class Gdk::MiraclePainter < Gtk::Object
   def destroy
     def self.tree
       raise DestroyedError.new end
-    def self.to_message
+    def self.message
       raise DestroyedError.new end
     def self.p_message
       raise DestroyedError.new end
@@ -313,7 +319,11 @@ class Gdk::MiraclePainter < Gtk::Object
     layout end
 
   def header_left_markup
-    Pango.parse_markup("<b>#{Pango.escape(message[:user][:idname])}</b> #{Pango.escape(message[:user][:name] || '')}")
+    if message.user[:idname]
+      Pango.parse_markup("<b>#{Pango.escape(message.user.idname)}</b> #{Pango.escape(message.user.name || '')}")
+    else
+      Pango.parse_markup(Pango.escape(message.user.name || ''))
+    end
   end
 
   # ヘッダ（右）のための Pango::Layout のインスタンスを返す
@@ -347,15 +357,16 @@ class Gdk::MiraclePainter < Gtk::Object
   # pixbufを組み立てる
   def gen_pixbuf
     @pixmap = gen_pixmap
-    Gdk::Pixbuf.from_drawable(nil, @pixmap, 0, 0, width, height)
+    GdkPixbuf::Pixbuf.from_drawable(nil, @pixmap, 0, 0, width, height)
   end
 
   # アイコンのpixbufを返す
   def main_icon
-    @main_icon ||= Gdk::WebImageLoader.pixbuf(message[:user][:profile_image_url], icon_width, icon_height){ |pixbuf|
-      if not destroyed?
-        @main_icon = pixbuf
-        on_modify end } end
+    @main_icon ||= message.user.icon.load_pixbuf(width: icon_width, height: icon_height){|pixbuf|
+      @main_icon = pixbuf
+      on_modify
+    }
+  end
 
   # 背景色を返す
   def get_backgroundcolor
@@ -398,7 +409,7 @@ class Gdk::MiraclePainter < Gtk::Object
       context.set_source_pixbuf(main_icon)
       context.paint
     }
-    if not (message.to_message.system?)
+    if not (message.system?)
       render_icon_over_button(context) end
   end
 
@@ -406,7 +417,7 @@ class Gdk::MiraclePainter < Gtk::Object
     context.save do
       context.save do
         context.translate(pos.main_icon.x, pos.main_icon.y + icon_height*13/14)
-        context.set_source_pixbuf(Gdk::WebImageLoader.pixbuf(Cairo::SpecialEdge::FOOTER_URL, icon_width, icon_width*9/20){|_pb, _s| on_modify })
+        context.set_source_pixbuf(gb_foot.load_pixbuf(width: icon_width, height: icon_width*9/20){|_pb, _s| on_modify })
         context.paint
       end
       context.translate(pos.main_icon.x, pos.main_icon.y)
@@ -417,7 +428,7 @@ class Gdk::MiraclePainter < Gtk::Object
       context.set_source_pixbuf(main_icon)
       context.fill
     end
-    if not (message.to_message.system?)
+    if not (message.system?)
       render_icon_over_button(context) end
   end
 
@@ -455,6 +466,18 @@ class Gdk::MiraclePainter < Gtk::Object
       context.translate(pos.main_text.x, pos.main_text.y)
       context.show_pango_layout(main_message(context)) } end
 
+  def gb_foot
+    self.class.gb_foot
+  end
+
+  class << self
+    memoize def gb_foot
+      Enumerator.new{|y|
+        Plugin.filtering(:photo_filter, Cairo::SpecialEdge::FOOTER_URL, y)
+      }.first
+    end
+  end
+
   class DestroyedError < Exception
   end
 
