@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 Plugin.create :home_timeline do
-  tab :home_timeline, "Home Timeline" do
-    set_icon Skin.get("timeline.png")
+  tab :home_timeline, _("Home Timeline") do
+    set_icon Skin['timeline.png']
     timeline :home_timeline end
 
   on_update do |s, ms|
