@@ -2,10 +2,6 @@
 
 require 'moneta'
 
-module Plugin::ImageFileCache
-  CacheThread = SerialThreadGroup.new
-end
-
 Plugin.create :image_file_cache do
 
   @queue = Delayer.generate_class(priority: %i[none check_subdirs check_dirs],
@@ -17,19 +13,16 @@ Plugin.create :image_file_cache do
                                    this.adapter(:File, dir: dir)
                                  } }.(@cache_directory))
 
-  # appear_limit 回TLに出現したユーザはキャッシュに登録する
-  # (30分ツイートしなければカウンタはリセット)
-  on_appear do |messages|
-    messages.deach do |message|
-      image_url = message.user[:profile_image_url]
-      if not @db.key?(image_url)
-        appear_counter[image_url] ||= 0
-        appear_counter[image_url] += 1
-        if appear_counter[image_url] > appear_limit
-          Plugin.call(:image_file_cache_cache, image_url) end end end end
-
   on_image_file_cache_cache do |url|
-    cache_it(url) end
+    photos = Enumerator.new{|y|
+      Plugin.filtering(:photo_filter, url, y)
+    }
+    Plugin.call(:image_file_cache_photo, photos.first)
+  end
+
+  on_image_file_cache_photo do |photo|
+    cache_it(photo)
+  end
 
   # キャッシュがあれば画像を返す
   filter_image_cache do |url, image, &stop|
@@ -42,22 +35,16 @@ Plugin.create :image_file_cache do
       error e
       [url, image] end end
 
-  def appear_counter
-    @appear_counter ||= TimeLimitedStorage.new end
-
-  # キャッシュする出現回数のしきい値を返す
-  def appear_limit
-    UserConfig[:image_file_cache_appear_limit] || 32 end
-
   # キャッシュの有効期限を秒単位で返す
   def cache_expire
     (UserConfig[:image_file_cache_expire] || 7) * 24 * 60 * 60 end
 
-  def cache_it(image_url)
-    Plugin::ImageFileCache::CacheThread.new do
-      raw = Gdk::WebImageLoader.get_raw_data(image_url)
-      if raw
-        @db[image_url] = raw end end end
+  def cache_it(photo)
+    notice "cache added #{photo.uri}"
+    photo.download.next{|downloaded|
+      @db[downloaded.uri.to_s] = downloaded.blob
+    }
+  end
 
   def check_subdirs(dir)
     @queue.new(:check_subdirs) do
@@ -65,7 +52,7 @@ Plugin.create :image_file_cache do
         .map{|x| File.join(dir, x) }
         .select{|x| FileTest.file?(x) }
         .each{|x|
-        Reserver.new((File.atime(x) rescue File.mtime(x)) + cache_expire) do
+        Reserver.new((File.atime(x) rescue File.mtime(x)) + cache_expire, thread: SerialThread) do
           notice "cache deleted #{x}"
           File.delete(x) if FileTest.file?(x)
           if Dir.foreach(dir).select{|y| File.file? File.join(dir, y) }.empty?
@@ -82,13 +69,13 @@ Plugin.create :image_file_cache do
         .each{|subdir|
         check_subdirs(File.join(@cache_directory, subdir))
       }
-      Reserver.new(cache_expire) do
+      Reserver.new(cache_expire, thread: SerialThread) do
         check_dirs end
     end
   end
 
   def _loop
-    Reserver.new(60) do
+    Reserver.new(60, thread: SerialThread) do
       if @queue
         @queue.run
         _loop  end end end
