@@ -2,10 +2,10 @@
 Plugin.create :message_favorite do
   message_fragment :favorited, "Favorite" do
     message = retriever
-    set_icon Skin.get('unfav.png')
+    set_icon Skin['unfav.png']
     user_list = Gtk::UserList.new
     begin
-      user_list.add_user Users.new(retriever.favorited_by.to_a)
+      user_list.add_user retriever.favorited_by
     rescue => err
       error err
     end
@@ -13,7 +13,7 @@ Plugin.create :message_favorite do
 
     on_favorite do |service, user, to_message|
       if to_message == message
-        user_list.add_user(Users.new([user])) end end
+        user_list.add_user([user]) end end
 
   end
 end
