@@ -32,14 +32,15 @@ module Plugin::Shortcutkey
         if commands[slug]
           icon = commands[slug][:icon]
           icon = icon.call(nil) if icon.is_a? Proc
+          icon = Retriever::Model(:photo)[icon] if icon
           if icon
-            iter[COLUMN_COMMAND_ICON] = Gdk::WebImageLoader.pixbuf(icon, 16, 16){ |pixbuf|
+            iter[COLUMN_COMMAND_ICON] = icon.load_pixbuf(width: 16, height: 16){ |pixbuf|
               if not destroyed?
                 iter[COLUMN_COMMAND_ICON] = pixbuf end } end end } end
 
     def column_schemer
       [{:kind => :text, :widget => :keyconfig, :type => String, :label => @plugin._('キーバインド')},
-       [{:kind => :pixbuf, :type => Gdk::Pixbuf, :label => @plugin._('機能名')},
+       [{:kind => :pixbuf, :type => GdkPixbuf::Pixbuf, :label => @plugin._('機能名')},
         {:kind => :text, :type => String, :expand => true}],
        {:kind => :text, :widget => :chooseone, :args => [Hash[Plugin.filtering(:command, Hash.new).first.values.map{ |x|
                                                             [x[:slug], x[:name]]
@@ -138,7 +139,7 @@ module Plugin::Shortcutkey
       treeview = CommandList.new(@plugin, results)
       scrollbar = ::Gtk::VScrollbar.new(treeview.vadjustment)
       filter_entry = treeview.filter_entry = Gtk::Entry.new
-      filter_entry.primary_icon_pixbuf = Gdk::WebImageLoader.pixbuf(MUI::Skin.get("search.png"), 24, 24)
+      filter_entry.primary_icon_pixbuf = Skin['search.png'].pixbuf(width: 24, height: 24)
       filter_entry.ssc(:changed){
         treeview.model.refilter
         false }
@@ -169,7 +170,7 @@ module Plugin::Shortcutkey
       def initialize(plugin, results)
         type_strict plugin => Plugin
         @plugin = plugin
-        super(::Gtk::TreeModelFilter.new(::Gtk::TreeStore.new(::Gdk::Pixbuf, String, Symbol)))
+        super(::Gtk::TreeModelFilter.new(::Gtk::TreeStore.new(::GdkPixbuf::Pixbuf, String, Symbol)))
         model.set_visible_func{ |model, iter|
           if defined?(@filter_entry) and @filter_entry
             iter_match(iter, @filter_entry.text)
@@ -183,14 +184,14 @@ module Plugin::Shortcutkey
           iter[COL_NAME] = k.to_s
           iter
         }
-        commands = Plugin.filtering(:command, Hash.new).first.map{ |slug, command|
+        Plugin.filtering(:command, Hash.new).first.map{ |slug, command|
           iter = model.model.append(parents[command[:role]])
-          icon = command[:icon]
-          icon = icon.call(nil) if icon.is_a? Proc
+          icon = icon_model(command[:icon])
           if icon
-            iter[COL_ICON] = Gdk::WebImageLoader.pixbuf(icon, 16, 16){ |pixbuf|
-              if not destroyed?
-                iter[COL_ICON] = pixbuf end } end
+            iter[COL_ICON] = icon.load_pixbuf(width: 16, height: 16) do |pixbuf|
+              iter[COL_ICON] = pixbuf if not destroyed?
+            end
+          end
           name = command[:name]
           name = name.call(nil) if name.is_a? Proc
           iter[COL_NAME] = name
@@ -214,6 +215,17 @@ module Plugin::Shortcutkey
 
       private
 
+      def icon_model(icon)
+        case icon
+        when Proc
+          icon_model(icon.call(nil))
+        when Retriever::Model
+          icon
+        when String, URI, Addressable::URI, Retriever::URI
+          Enumerator.new{|y| Plugin.filtering(:photo_filter, icon, y) }.first
+        end
+      end
+
       def iter_match(iter, text)
         [COL_NAME, COL_SLUG].any?{ |column|
           iter[column].to_s.include?(text)
@@ -223,9 +235,3 @@ module Plugin::Shortcutkey
 
   end
 end
-
-
-
-
-
-
