@@ -91,17 +91,30 @@ class UserConfig
 
     :mumble_basic_font => 'Sans 10',
     :mumble_basic_color => [0, 0, 0],
-    :mumble_reply_font => 'Sans 8',
-    :mumble_reply_color => [255*0x66, 255*0x66, 255*0x66],
+    :reply_text_font => 'Sans 8',
+    :reply_text_color => [0, 0, 0],
+    :quote_text_font => 'Sans 8',
+    :quote_text_color => [0, 0, 0],
     :mumble_basic_left_font => 'Sans 10',
     :mumble_basic_left_color => [0, 0, 0],
     :mumble_basic_right_font => 'Sans 10',
-    :mumble_basic_right_color => [255*0x99, 255*0x99, 255*0x99],
+    :mumble_basic_right_color => [0x9999, 0x9999, 0x9999],
 
-    :mumble_basic_bg => [65535, 65535, 65535],
-    :mumble_reply_bg => [65535, 255*222, 255*222],
-    :mumble_self_bg => [65535, 65535, 255*222],
-    :mumble_selected_bg => [255*222, 255*222, 65535],
+    :mumble_basic_bg => [0xffff, 0xffff, 0xffff],
+    :mumble_reply_bg => [0xffff, 0xdede, 0xdede],
+    :mumble_self_bg => [0xffff, 0xffff, 0xdede],
+    :mumble_selected_bg => [0xdede, 0xdede, 0xffff],
+    :replyviewer_background_color => [0xffff, 0xdede, 0xdede],
+    :quote_background_color => [0xffff, 0xffff, 0xffff],
+
+    :reply_icon_size => 32,
+    :quote_icon_size => 32,
+
+    :reply_present_policy => %i<header icon edge>,
+    :reply_edge => :solid,
+
+    :quote_present_policy => %i<header icon edge>,
+    :quote_edge => :solid,
 
     # 右クリックメニューの並び順
     :mumble_contextmenu_order => ['copy_selected_region',
@@ -120,13 +133,40 @@ class UserConfig
     :activity_mute_kind => ["error"],
     :activity_show_timeline => ["system", "achievement"],
 
-    :notification_enable => true
+    :notification_enable => true,
+
+    :reply_text_max_line_count => 10,
+    :quote_text_max_line_count => 10,
+    :reply_clicked_action => :open,
+    :quote_clicked_action => :open,
+
+    :intent_selector_rules => [{:uuid=>"8ab31d89-6d5f-4765-bb99-7a93ce5b1139",
+                                :intent=>:user_detail_view_twitter_user,
+                                :model=>"",
+                                :str=>"https://twitter.com/",
+                                :rule=>"start"},
+                               {:uuid=>"c0095e59-75da-4177-98e0-d4955ece1d20",
+                                :intent=>:message_detail_view_twitter_tweet,
+                                :model=>"",
+                                :str=>"https://twitter.com/",
+                                :rule=>"start"}]
   }
 
   @@watcher = Hash.new{ [] }
   @@watcher_id = Hash.new
   @@watcher_id_count = 0
 
+  # キーに対応する値が存在するかを調べる。
+  # 値が設定されていれば、それが _nil_ や _false_ であっても _true_ を返す
+  # ==== Args
+  # [key] Symbol キー
+  # ==== Return
+  # [true] 存在する
+  # [false] 存在しない
+  def self.include?(key)
+    UserConfig.instance.include?(key) || @@defaults.include?(key)
+  end
+
   # 設定名 _key_ にたいする値を取り出す
   # 値が設定されていない場合、nilを返す。
   def self.[](key)
@@ -181,6 +221,20 @@ class UserConfig
         unless activity_show_statusbar.include? 'streaming_status'
           activity_show_statusbar << 'streaming_status'
           UserConfig[:activity_show_statusbar] = activity_show_statusbar end end
+      if last_boot_version < [3, 4, 0, 0]
+        UserConfig[:replyviewer_background_color] = UserConfig[:mumble_reply_bg]
+        UserConfig[:quote_background_color] = UserConfig[:mumble_basic_bg]
+        UserConfig[:reply_text_font] = UserConfig[:mumble_reply_font] || 'Sans 8'
+        UserConfig[:reply_text_color] = UserConfig[:mumble_reply_color] || [0x6666, 0x6666, 0x6666]
+        UserConfig[:reply_icon_size] = 24
+        UserConfig[:quote_text_font] = UserConfig[:reply_text_font] || 'Sans 8'
+        UserConfig[:quote_text_color] = UserConfig[:reply_text_color]
+        UserConfig[:reply_present_policy] = %i<icon>
+        UserConfig[:quote_edge] = :floating
+        UserConfig[:reply_text_max_line_count] = 3
+        UserConfig[:reply_clicked_action] = nil
+        UserConfig[:quote_clicked_action] = :smartthread
+      end
     end
   end
 
